Index: binaries/data/mods/mod/gui/common/modern/sprites.xml
===================================================================
--- binaries/data/mods/mod/gui/common/modern/sprites.xml	(revision 16292)
+++ binaries/data/mods/mod/gui/common/modern/sprites.xml	(working copy)
@@ -626,4 +626,20 @@
 			texture_size="0 0 24 24"
 		/>
 	</sprite>
+	<!--
+	==========================================
+	LOGOS
+	==========================================
+	-->
+	<sprite name="productLogo">
+		<image 	texture="global/modern/logo/0ad_logo.png"
+			real_texture_placement="0 0 256 128"
+			size="0 -5% 100% 105%"
+		/>
+	</sprite>
+	<sprite name="companyLogo">
+		<image 	texture="global/modern/logo/wfg_logo_white.png"
+			real_texture_placement="0 0 32 32"
+		/>
+	</sprite>
 </sprites>
Index: binaries/data/mods/mod/gui/common/modern/styles.xml
===================================================================
--- binaries/data/mods/mod/gui/common/modern/styles.xml	(revision 16292)
+++ binaries/data/mods/mod/gui/common/modern/styles.xml	(working copy)
@@ -155,4 +155,15 @@
 		text_valign="center"
 		sound_pressed="audio/interface/ui/ui_button_click.ogg"
 	/>
+	<style name="ModernButtonRedFancy"
+		sprite="ModernButtonRed"
+		sprite_disabled="ModernButtonRedDisabled"
+		sprite_over="ModernButtonYellowOver"
+		sprite_pressed="ModernButtonYellow"
+		font="sans-bold-stroke-14"
+		textcolor="white"
+		text_align="center"
+		text_valign="center"
+		sound_pressed="audio/interface/ui/ui_button_click.ogg"
+	/>
 </styles>
Index: binaries/data/mods/public/gui/common/common_sprites.xml
===================================================================
--- binaries/data/mods/public/gui/common/common_sprites.xml	(revision 16292)
+++ binaries/data/mods/public/gui/common/common_sprites.xml	(working copy)
@@ -1,28 +1,8 @@
 <?xml version="1.0" encoding="utf-8"?>
 
 <sprites>
-
 	<!--
 	==========================================
-	LOGOS
-	==========================================
-	-->
-
-	<sprite name="productLogo">
-		<image 	texture="pregame/shell/logo/0ad_logo.png"
-			real_texture_placement="0 0 256 128"
-			size="0 -5% 100% 105%"
-		/>
-	</sprite>
-
-	<sprite name="companyLogo">
-		<image 	texture="pregame/shell/logo/wfg_logo_white.png"
-			real_texture_placement="0 0 32 32"
-		/>
-	</sprite>
-
-	<!--
-	==========================================
 	BACKCOLOR SPRITES
 	==========================================
 	-->
@@ -119,81 +99,7 @@
 	==========================================
 	-->
 
-	<!-- MainMenuPanel -->
-	<sprite name="MainMenuPanel">
-		<image	texture="global/tile/stone_background.png"
-			real_texture_placement="28 0 292 264"
-			texture_size="0 0 240 240"
-		/>
 
-		<image	texture="pregame/shading/menu_panel_background_shading.png"
-			texture_size="0 0 100% 100%"
-			size="0 0 100% 100%"
-		/>
-
-		<!-- sides -->
-<!--		<image	backcolor="230 190 80"
-			size="2 0 100%-2 2"
-		/>
-		<image	backcolor="230 190 80"
-			size="100%-2 0 100% 100%"
-		/>
-		<image	backcolor="230 190 80"
-			size="2 100%-2 100%-2 100%"
-		/>
-		<image	backcolor="230 190 80"
-			size="0 0 2 100%"
-		/>-->
-
-                <!-- top -->
-		<image	backcolor="230 190 80"
-			size="2 0 100%-2 2"
-		/>
-
-                <!-- bottom -->
-		<image	backcolor="230 190 80"
-			size="2 100%-2 100%-2 100%"
-		/>
-
-                <!-- left -->
-		<image	backcolor="230 190 80"
-			size="0 0 2 100%"
-		/>
-	</sprite>
-
-        <!-- MainMenuPanelRightBorder -->
-        <sprite name="MainMenuPanelRightBorder">
-                <!-- right -->
-		<image	backcolor="230 190 80"
-			size="0 0 100% 100%"
-		/>
-        </sprite>
-
-	<!-- SubmenuPanel -->
-	<sprite name="SubmenuPanel">
-		<image	texture="global/tile/stone_background.png"
-			real_texture_placement="32 0 292 264"
-			texture_size="0 0 240 240"
-		/>
-
-		<image	texture="pregame/shading/menu_panel_background_shading.png"
-			texture_size="0 0 100% 100%"
-			size="0 0 100% 100%"
-		/>
-
-		<!-- sides -->
-		<image	backcolor="230 190 80"
-			size="0 0 100%-2 2"
-		/>
-		<image	backcolor="230 190 80"
-			size="100%-2 0 100% 100%"
-		/>
-		<image	backcolor="230 190 80"
-			size="0 100%-2 100%-2 100%"
-		/>
-		<!-- no left border here -->
-	</sprite>
-
 	<!-- TranslucentPanel -->
 	<sprite name="TranslucentPanelThinBorder">
 		<image 	backcolor="0 0 0 85"
Index: binaries/data/mods/public/gui/common/common_styles.xml
===================================================================
--- binaries/data/mods/public/gui/common/common_styles.xml	(revision 16292)
+++ binaries/data/mods/public/gui/common/common_styles.xml	(working copy)
@@ -142,20 +142,6 @@
 		text_valign="top"
 	/>
 
-	<style 	name="MainMenuPanel"
-		sprite="MainMenuPanel"
-		buffer_zone="10"
-		text_align="left"
-		text_valign="top"
-	/>
-
-        <style 	name="SubmenuPanel"
-		sprite="SubmenuPanel"
-		buffer_zone="10"
-		text_align="left"
-		text_valign="top"
-	/>
-
 	<style 	name="LargeStonePanelThinBorder"
 		sprite="LargeStonePanelThinBorder"
 		buffer_zone="10"
Index: binaries/data/mods/public/gui/page_pregame.xml
===================================================================
--- binaries/data/mods/public/gui/page_pregame.xml	(revision 16292)
+++ binaries/data/mods/public/gui/page_pregame.xml	(working copy)
@@ -4,13 +4,7 @@
     <include>common/modern/styles.xml</include>
     <include>common/modern/sprites.xml</include>
 
-    <include>common/setup.xml</include>
-    <include>common/sprite1.xml</include>
-    <include>common/styles.xml</include>
-    <include>common/common_sprites.xml</include>
-    <include>common/common_styles.xml</include>
-    <include>common/init.xml</include>
-
+	<include>pregame/setup.xml</include>
     <include>pregame/sprites.xml</include>
     <include>pregame/styles.xml</include>
     <include>pregame/mainmenu.xml</include>
Index: binaries/data/mods/public/gui/pregame/mainmenu.js
===================================================================
--- binaries/data/mods/public/gui/pregame/mainmenu.js	(revision 16292)
+++ binaries/data/mods/public/gui/pregame/mainmenu.js	(working copy)
@@ -1,5 +1,5 @@
 var userReportEnabledText; // contains the original version with "$status" placeholder
-var currentSubmenuType; // contains submenu type
+var currentSubmenuType, currentSubmenuCaller; // contains submenu type, submenu caller
 const MARGIN = 4; // menu border size
 const background = "hellenes1"; // Background type.
 
@@ -200,8 +200,12 @@
 }
 
 // Opens the menu by revealing the screen which contains the menu
-function openMenu(newSubmenu, position, buttonHeight, numButtons)
+function openMenu(context, newSubmenu, position, buttonHeight, numButtons)
 {
+	// Make button which opened submenu look like it stays selected
+	currentSubmenuCaller = context.name;
+	Engine.GetGUIObjectByName(currentSubmenuCaller).sprite = "ModernButtonYellow";
+
 	// switch to new submenu type
 	currentSubmenuType = newSubmenu;
 	Engine.GetGUIObjectByName(currentSubmenuType).hidden = false;
@@ -222,7 +226,9 @@
 // Closes the menu and resets position
 function closeMenu()
 {
-//	playButtonSound();
+	// 'un-select' button
+	if (currentSubmenuCaller)
+		Engine.GetGUIObjectByName(currentSubmenuCaller).sprite = "ModernButtonRed";
 
 	// remove old submenu type
 	Engine.GetGUIObjectByName(currentSubmenuType).hidden = true;
@@ -279,7 +285,7 @@
 	closeMenu();
 	var btCaptions = [translate("No"), translate("Yes")];
 	var btCode = [null, Engine.Exit];
-	messageBox(400, 200, translate("Are you sure you want to quit 0 A.D.?"), translate("Confirmation"), 0, btCaptions, btCode);
+	messageBox(400, 200, translate("Are you sure you want to exit 0 A.D. Empires Ascendant?"), translate("Confirmation"), 0, btCaptions, btCode);
 }
 
 function pressedScenarioEditorButton()
